from enum import Enum

class QRImageTemplate(str, Enum):
    TEMPLATE1 = "template1"
    TEMPLATE1_COLOR = "template1_color"
    TEMPLATE2 = "template2"
    TEMPLATE2_COLOR = "template2_color"
    TEMPLATE4 = "template4"
    TEMPLATE3_COLOR = "template3_color"
